@@ -64,11 +64,11 @@ QString QHiMDTrack::codecname() const
 
 QTime QHiMDTrack::duration() const
 {
-    QTime t;
+    QTime t(0,0,0);
     if(trackslot != 0)
         return t.addSecs(ti.seconds);
     else
-        return t;
+        return QTime();
 }
 
 QDateTime QHiMDTrack::recdate() const
@@ -259,8 +259,9 @@ QString QHiMDTracksModel::open(const QString & path)
         return QString::fromUtf8(status.statusmsg);
     }
     close();
+    beginResetModel();
     himd = newhimd;
-    reset();	/* inform views that the model contents changed */
+    endResetModel();	/* inform views that the model contents changed */
     return QString();
 }
 
@@ -274,9 +275,10 @@ void QHiMDTracksModel::close()
     struct himd * oldhimd;
     if(!himd)
         return;
+    beginResetModel();
     oldhimd = himd;
     himd = NULL;
-    reset();	/* inform views that the model contents changed */
+    endResetModel();	/* inform views that the model contents changed */
     himd_close(oldhimd);
     delete oldhimd;
 }
